[llvm-commits] [llvm] r132774 - /llvm/trunk/lib/Target/TargetLibraryInfo.cpp

Duncan Sands baldrick at free.fr
Thu Jun 9 04:11:45 PDT 2011


Author: baldrick
Date: Thu Jun  9 06:11:45 2011
New Revision: 132774

URL: http://llvm.org/viewvc/llvm-project?rev=132774&view=rev
Log:
Enable printf() to iprintf() optimization for the TCE target.
Patch by Pekka Jaaskelainen. 

Modified:
    llvm/trunk/lib/Target/TargetLibraryInfo.cpp

Modified: llvm/trunk/lib/Target/TargetLibraryInfo.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Target/TargetLibraryInfo.cpp?rev=132774&r1=132773&r2=132774&view=diff
==============================================================================
--- llvm/trunk/lib/Target/TargetLibraryInfo.cpp (original)
+++ llvm/trunk/lib/Target/TargetLibraryInfo.cpp Thu Jun  9 06:11:45 2011
@@ -38,8 +38,8 @@
     TLI.setUnavailable(LibFunc::memset_pattern16);
   }
 
-  // iprintf and friends are only available on XCore.
-  if (T.getArch() != Triple::xcore) {
+  // iprintf and friends are only available on XCore and TCE.
+  if (T.getArch() != Triple::xcore && T.getArch() != Triple::tce) {
     TLI.setUnavailable(LibFunc::iprintf);
     TLI.setUnavailable(LibFunc::siprintf);
     TLI.setUnavailable(LibFunc::fiprintf);





More information about the llvm-commits mailing list